==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/am-ET/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'About Locations',
    'about_locations'           => 'Locations are used to track location information for users, assets, and other items',
    'assets_rtd'                => 'ንብረቶች', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'ID',
    'city'                      => 'City',
    'state'                     => 'State',
    'country'                   => 'Country',
    'create'                    => 'Create Location',
    'update'                    => 'Update Location',
    'print_assigned'            => 'Print Assigned',
    'print_all_assigned'        => 'Print All Assigned',
    'name'                      => 'Location Name',
    'address'                   => 'አድራሻ',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Postal Code',
    'locations'                 => 'Locations',
    'parent'                    => 'Parent',
    'currency'                  => 'Location Currency',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'User Name',
    'department'                => 'Department',
    'location'                  => 'Location',
    'asset_tag'                 => 'Assets Tag',
    'asset_name'                => 'Name',
    'asset_category'            => 'Category',
    'asset_manufacturer'        => 'Manufacturer',
    'asset_model'               => 'ሞዴል',
    'asset_serial'              => 'Serial',
    'asset_location'            => 'Location',
    'asset_checked_out'         => 'Checked Out',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => 'Date:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/am-ET/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'About Locations',
    'about_locations'           => 'Locations are used to track location information for users, assets, and other items',
    'assets_rtd'                => 'ንብረቶች', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Assets Assigned',
    'id'                        => 'መለያ',
    'city'                      => 'City',
    'state'                     => 'State',
    'country'                   => 'Country',
    'create'                    => 'Create Location',
    'update'                    => 'Update Location',
    'print_assigned'            => 'Print Assigned',
    'print_all_assigned'        => 'Print All Assigned',
    'name'                      => 'Location Name',
    'address'                   => 'አድራሻ',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Postal Code',
    'locations'                 => 'Locations',
    'parent'                    => 'ዋና መደብ',
    'currency'                  => 'Location Currency',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'User Name',
    'department'                => 'Department',
    'location'                  => 'Location',
    'asset_tag'                 => 'Assets Tag',
    'asset_name'                => 'Name',
    'asset_category'            => 'Category',
    'asset_manufacturer'        => 'Manufacturer',
    'asset_model'               => 'ሞዴል',
    'asset_serial'              => 'Serial',
    'asset_location'            => 'Location',
    'asset_checked_out'         => 'Checked Out',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => 'Date:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];
